@@ -44,20 +44,29 @@ async def index(request: web.Request) -> web.Response:
         "grafana": "/grafana/",
         "dashboard": "/",
         "hosted_dashboard": "/metrics/redirect",
+        "webterminal": "/webterminal/",
+        "anyscaled": "/anyscaled/",
     }
 
     if not token or not redirect_to or redirect_to not in path.keys():
         return web.Response(
             text="token or redirect_to field not found, "
             "maybe you forgot to add `?token=..&redirect_to.` field? "
-            "redirect_to={tensorboard, dashboard, grafana}.",
+            "redirect_to={tensorboard, dashboard, grafana, webterminal}.",
             status=401,
         )
     # TODO(simon): set token on startup
     known_token.add(token)
 
     resp = web.HTTPFound(path[redirect_to])
-    resp.set_cookie("anyscale-token", token)
+    if redirect_to == "webterminal":
+        # The default for samesite is None currently but it is migrating
+        # to Lax for most browser. Explicitly setting it here will
+        # enable beta.anyscale.com to communicate with webterminal service.
+        # https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie/SameSite
+        resp.set_cookie("anyscale-token", token, secure=True, samesite="None")
+    else:
+        resp.set_cookie("anyscale-token", token, secure=True)
     return resp
 
 
