@@ -124,6 +124,92 @@ def anyscale_up(
     )
 
 
+@click.command(
+    name="_up",
+    context_settings=dict(ignore_unknown_options=True,),
+    help="Start or update a session based on the current project configuration.",
+    hidden=True,
+)
+@click.argument("session-name", required=False)
+@click.option(
+    "--config", "config", help="Cluster to start session with.", default=None,
+)
+@click.option(
+    "--no-restart",
+    is_flag=True,
+    default=False,
+    help=(
+        "Whether to skip restarting Ray services during the update. "
+        "This avoids interrupting running jobs."
+    ),
+)
+@click.option(
+    "--restart-only",
+    is_flag=True,
+    default=False,
+    help=(
+        "Whether to skip running setup commands and only restart Ray. "
+        "This cannot be used with 'no-restart'."
+    ),
+)
+@click.option(
+    "--min-workers",
+    required=False,
+    type=int,
+    help="Override the configured min worker node count for the cluster.",
+)
+@click.option(
+    "--max-workers",
+    required=False,
+    type=int,
+    help="Override the configured max worker node count for the cluster.",
+)
+@click.option(
+    "--disable-sync",
+    is_flag=True,
+    default=False,
+    help=(
+        "Disables syncing file mounts and project directory. This is "
+        "useful when 'restart-only' is set and file syncing takes a long time."
+    ),
+)
+@click.option("--cloud-id", required=False, help="Id of the cloud to use", default=None)
+@click.option(
+    "--cloud-name", required=False, help="Name of the cloud to use", default=None
+)
+@click.option(
+    "--yes", "-y", is_flag=True, default=False, help="Don't ask for confirmation."
+)
+@click.option("--verbose", "-v", help="Print out more information", is_flag=True)
+def anyscale_up_internal(
+    session_name: Optional[str],
+    config: Optional[str],
+    min_workers: Optional[int],
+    max_workers: Optional[int],
+    no_restart: bool,
+    restart_only: bool,
+    disable_sync: bool,
+    cloud_id: Optional[str],
+    cloud_name: Optional[str],
+    yes: bool,
+    verbose: bool,
+) -> None:
+    session_controller = SessionController()
+    session_controller.up_internal(
+        session_name,
+        config,
+        min_workers,
+        max_workers,
+        no_restart,
+        restart_only,
+        disable_sync,
+        cloud_id,
+        cloud_name,
+        yes,
+        verbose=verbose,
+    )
+
+
 @click.command(name="ssh", help="SSH into head node of cluster.")
 @click.argument(
     "session-name", type=str, required=False, default=None, envvar="SESSION_NAME"
@@ -145,7 +231,7 @@ If there is only a single session running, this command without arguments will
 default to that session.""",
 )
 @click.argument("session-name", type=str, required=False, default=None)
-@click.option("--verbose", help="Show output from autosync.", is_flag=True)
+@click.option("--verbose", help="Show output from autopush.", is_flag=True)
 @click.option(
     "-d",
     "--delete",
@@ -171,6 +257,7 @@ the state of your local project with the Anyscale session that you specify.
 
 If there is only a single session running, this command without arguments will
 default to that session.""",
+    hidden=True,  # HIDDEN cuz deprecated
 )
 @click.argument("session-name", type=str, required=False, default=None)
 @click.option("--verbose", help="Show output from autosync.", is_flag=True)
@@ -191,14 +278,7 @@ default to that session.""",
 def anyscale_autosync(
     session_name: Optional[str], verbose: bool, delete: bool, ignore_errors: bool,
 ) -> None:
-    print(
-        "Deprecation warning: autosync has been renamed to autopush. autosync will "
-        "be removed in a future version."
-    )
-    session_controller = SessionController()
-    session_controller.autopush(
-        session_name, verbose, delete=delete, ignore_errors=ignore_errors
-    )
+    raise click.ClickException("Error: autosync has been renamed to autopush")
 
 
 @click.command(name="push", help="Push current project to session.")
@@ -248,9 +328,7 @@ def anyscale_push(
     all_nodes: bool,
 ) -> None:
     session_controller = SessionController()
-    session_controller.anyscale_push_session(
-        ctx, session_name, source, target, config, all_nodes
-    )
+    session_controller.push(session_name, source, target, config, all_nodes)
 
 
 @click.command(name="pull", help="Pull session")
