@@ -3,7 +3,6 @@ import logging
 from typing import Dict, List, Optional
 
 import click
-import ray.ray_constants
 
 from anyscale.auth_proxy import app as auth_proxy_app
 import anyscale.legacy_projects as ray_scripts
@@ -24,7 +23,6 @@ from anyscale.util import (
 )
 
 
-logging.basicConfig(format=ray.ray_constants.LOGGER_FORMAT)
 logger = logging.getLogger(__file__)
 logging.getLogger("botocore").setLevel(logging.CRITICAL)
 
@@ -81,6 +79,7 @@ def session_logs(name: Optional[str], command_id: Optional[int]) -> None:
     print(resp_err["result"]["lines"])
 
 
+# Note: These functions are not normally updated, please cc yiran or ijrsvt on changes.
 @session_cli.command(
     name="upload_command_logs", help="Upload logs for a command.", hidden=True
 )
@@ -107,6 +106,7 @@ def session_upload_command_logs(command_id: Optional[str]) -> None:
             copy_file(True, source, target, download=False)
 
 
+# Note: These functions are not normally updated, please cc yiran or ijrsvt on changes.
 @session_cli.command(
     name="finish_command", help="Finish executing a command.", hidden=True
 )
@@ -131,6 +131,7 @@ def session_finish_command(command_id: str, stop: bool, terminate: bool) -> None
     )
 
 
+# Note: These functions are not normally updated, please cc yiran or ijrsvt on changes.
 @session_cli.command(name="auth_start", help="Start the auth proxy", hidden=True)
 def auth_start() -> None:
     from aiohttp import web
@@ -138,6 +139,24 @@ def auth_start() -> None:
     web.run_app(auth_proxy_app)
 
 
+@session_cli.command(
+    name="web_terminal_server", help="Start the web terminal server", hidden=True
+)
+@click.option(
+    "--deploy-environment",
+    help="Anyscale deployment type (development, test, staging, production)",
+    type=str,
+    required=True,
+)
+@click.option(
+    "--use-debugger", help="Activate the Anyscale debugger.", is_flag=True,
+)
+def web_terminal_server(deploy_environment: str, use_debugger: bool) -> None:
+    from anyscale.webterminal.webterminal import main
+
+    main(deploy_environment, use_debugger)
+
+
 @click.command(
     name="start",
     context_settings=dict(ignore_unknown_options=True,),
