@@ -4,16 +4,17 @@ Fetches data required and formats output for `anyscale cloud` commands.
 
 import json
 import os
-import time
 from typing import Optional
 
+import boto3
 from click import ClickException
 from openapi_client.rest import ApiException  # type: ignore
 
 from anyscale.api import get_api_client
 from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
+from anyscale.client.openapi_client.models.cloud_config import CloudConfig  # type: ignore
 from anyscale.client.openapi_client.models.write_cloud import WriteCloud  # type: ignore
-from anyscale.cloud import get_cloud_id_and_name
+from anyscale.cloud import get_cloud_id_and_name, get_cloud_json_from_id
 import anyscale.conf
 from anyscale.util import (
     _get_role,
@@ -84,6 +85,8 @@ class CloudController(object):
             )
 
     def setup_aws(self, region: str, name: str) -> None:
+        from ray.autoscaler._private.aws.config import DEFAULT_RAY_IAM_ROLE
+
         os.environ["AWS_DEFAULT_REGION"] = region
         regions_available = get_available_regions()
         if region not in regions_available:
@@ -101,9 +104,7 @@ class CloudController(object):
             user_info = self.api_client.get_user_info_api_v2_userinfo_get().result
 
         self.setup_aws_cross_account_role(region, user_info.id, name)
-
-        # Sleep for 5 seconds to make sure the policies take effect.
-        time.sleep(5)
+        self.setup_aws_ray_role(region, DEFAULT_RAY_IAM_ROLE)
 
         print("AWS credentials setup complete!")
         print(
@@ -157,3 +158,86 @@ class CloudController(object):
                     name=name,
                 )
             )
+
+    def setup_aws_ray_role(self, region: str, role_name: str) -> None:
+        iam = boto3.resource("iam", region_name=region)
+
+        role = _get_role(role_name, region)
+        if role is None:
+            iam.create_role(
+                RoleName=role_name,
+                AssumeRolePolicyDocument=json.dumps(
+                    {
+                        "Version": "2012-10-17",
+                        "Statement": {
+                            "Effect": "Allow",
+                            "Principal": {"Service": ["ec2.amazonaws.com"]},
+                            "Action": "sts:AssumeRole",
+                        },
+                    }
+                ),
+            )
+
+            role = _get_role(role_name, region)
+
+        # Default permissions (copied from upstream)
+        role.attach_policy(PolicyArn="arn:aws:iam::aws:policy/AmazonEC2FullAccess")
+        role.attach_policy(PolicyArn="arn:aws:iam::aws:policy/AmazonS3FullAccess")
+
+        # Also attach a role to allow it to launch more nodes with itself
+        role.Policy("PassRoleToSelf").put(
+            PolicyDocument=json.dumps(
+                {
+                    "Version": "2012-10-17",
+                    "Statement": [
+                        {
+                            "Sid": "PassRoleToSelf",
+                            "Effect": "Allow",
+                            "Action": "iam:PassRole",
+                            "Resource": role.arn,
+                        }
+                    ],
+                }
+            )
+        )
+
+    def update_cloud_config(
+        self,
+        cloud_name: Optional[str],
+        cloud_id: Optional[str],
+        max_stopped_instances: int,
+    ) -> None:
+        """Updates a cloud's configuration by name or id.
+
+        Currently the only supported option is "max_stopped_instances."
+        """
+
+        if not cloud_id and not cloud_name:
+            raise ClickException("Must either provide the cloud name or cloud id.")
+
+        cloud_id, cloud_name = get_cloud_id_and_name(
+            self.api_client, cloud_id, cloud_name
+        )
+
+        with format_api_exception(ApiException):
+            self.api_client.update_cloud_config_api_v2_clouds_cloud_id_config_put(
+                cloud_id=cloud_id,
+                cloud_config=CloudConfig(max_stopped_instances=max_stopped_instances),
+            )
+
+        print(f"Updated config for cloud '{cloud_name}' to:")
+        print(self.get_cloud_config(cloud_name=None, cloud_id=cloud_id))
+
+    def get_cloud_config(
+        self, cloud_name: Optional[str], cloud_id: Optional[str],
+    ) -> str:
+        """Get a cloud's current JSON configuration."""
+
+        if not cloud_id and not cloud_name:
+            raise ClickException("Must either provide the cloud name or cloud id.")
+
+        cloud_id, cloud_name = get_cloud_id_and_name(
+            self.api_client, cloud_id, cloud_name
+        )
+
+        return str(get_cloud_json_from_id(cloud_id, self.api_client)["config"])
