@@ -4,13 +4,10 @@ import os
 import subprocess
 import sys
 import tempfile
-from typing import Any, Optional, Tuple
+from typing import Any, Dict, Optional, Tuple, Union
 
 import click
 from openapi_client.rest import ApiException  # type: ignore
-from ray.autoscaler._private.commands import rsync
-from ray.autoscaler.sdk import get_head_node_ip
-import ray.scripts.scripts as autoscaler_scripts
 import yaml
 
 from anyscale import ANYSCALE_ENV
@@ -21,7 +18,7 @@ from anyscale.autosync_heartbeat import (
     perform_autopush_synchronization,
     perform_sync,
 )
-from anyscale.client.openapi_client import CreateSessionFromSnapshotOptions, Session, SessionFinishUpOptions, SessionState, SessionUpOptions, StopSessionOptions  # type: ignore
+from anyscale.client.openapi_client import CreateSessionFromSnapshotOptions, Session, SessionFinishUpOptions, SessionState, SessionUpOptions, SetupInitializeSessionOptions, StopSessionOptions  # type: ignore
 from anyscale.client.openapi_client.api.default_api import DefaultApi  # type: ignore
 from anyscale.cloud import get_cloud_id_and_name
 from anyscale.cluster_config import configure_for_session, get_cluster_config
@@ -40,6 +37,7 @@ from anyscale.util import (
     get_working_dir,
     install_anyscale_hooks,
     populate_session_args,
+    slugify,
     validate_cluster_configuration,
     wait_for_session_start,
 )
@@ -49,6 +47,18 @@ from anyscale.utils.aws_credentials_util import (
 from anyscale.utils.env_utils import set_env
 
 
+def get_head_node_ip(cluster_config: Union[Dict[str, Any], str]) -> Any:
+    from ray.autoscaler.sdk import get_head_node_ip
+
+    return get_head_node_ip(cluster_config)
+
+
+def rsync(*args: Any, **kwargs: Any) -> None:
+    from ray.autoscaler._private.commands import rsync as ray_rsync
+
+    ray_rsync(*args, **kwargs)
+
+
 class SessionController:
     def __init__(self, api_client: Optional[DefaultApi] = None):
         if api_client is None:
@@ -107,6 +117,8 @@ class SessionController:
         yes: bool,
         verbose: bool = False,
     ) -> None:
+        import ray.scripts.scripts as autoscaler_scripts
+
         # TODO(ilr) Split this into ~3 functions, look at jbai's comments on #1469
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
@@ -235,9 +247,11 @@ class SessionController:
                 startup_log_str = "".join(startup_log)
                 proc.communicate()
 
+                ray_up_succeeded = proc.returncode == 0
+
                 curr_head_ip = get_head_node_ip(renamed_config)
 
-                if curr_head_ip != prev_head_ip:
+                if curr_head_ip != prev_head_ip and ray_up_succeeded:
                     print("Setting up Jupyter lab, Ray dashboard, and autopush ...")
 
                 self.api_client.session_finish_up_api_v2_sessions_session_id_finish_up_post(
@@ -246,20 +260,110 @@ class SessionController:
                         startup_log=startup_log_str,
                         new_session=curr_head_ip != prev_head_ip,
                         head_node_ip=curr_head_ip,
+                        cluster_launch_errored=not ray_up_succeeded,
                     ),
                 )
-
+                # NOTE This call will raise an error if the session is in any of the following
+                # states (StartupErrored/Stopped/Terminated).
                 wait_for_session_start(project_id, session_name, self.api_client)
                 url = get_endpoint(f"/projects/{project_id}")
                 print(f"Session {session_name} started. View at {url}")
             except Exception as e:
-                self.api_client.stop_session_api_v2_sessions_session_id_stop_post(
+                raise click.ClickException("{}\nSession startup failed.".format(e))
+
+    def up_internal(
+        self,
+        session_name: Optional[str],
+        config: Optional[str],
+        min_workers: Optional[int],
+        max_workers: Optional[int],
+        no_restart: bool,
+        restart_only: bool,
+        disable_sync: bool,
+        cloud_id: Optional[str],
+        cloud_name: Optional[str],
+        yes: bool,
+        verbose: bool = False,
+    ) -> None:
+        # TODO(ilr) Split this into ~3 functions, look at jbai's comments on #1469
+        project_definition = load_project_or_throw()
+        project_id = get_project_id(project_definition.root)
+
+        if not session_name:
+            session_name = str(
+                self.api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get(
+                    project_id=project_id,
+                ).result.name
+            )
+        else:
+            session_name = slugify(session_name)
+
+        session_list = self.api_client.list_sessions_api_v2_sessions_get(
+            project_id=project_id, active_only=False, name=session_name
+        ).results
+
+        session_exists = len(session_list) > 0
+
+        if not session_exists:
+            config_attribute_provided = True
+            if not config:
+                config_attribute_provided = False
+                config = project_definition.cluster_yaml()
+
+            if not os.path.exists(config):
+                if config_attribute_provided:
+                    raise ValueError("Config file {} not found".format(config))
+                else:
+                    raise ValueError(
+                        "No config param provided and default config file session-default.yaml not found. Please provide a config file using the --config attribute."
+                    )
+
+        cluster_config = None
+
+        if config:
+            with open(config) as f:
+                cluster_config_filled = populate_session_args(f.read(), config)
+                cluster_config = yaml.safe_load(cluster_config_filled)
+
+            validate_cluster_configuration(config, cluster_config, self.api_client)
+
+        cloud_id, _ = get_cloud_id_and_name(self.api_client, cloud_id, cloud_name)
+        assert cloud_id is not None, "Failed to get cloud."
+
+        with format_api_exception(ApiException):
+            up_response = self.api_client.start_empty_session_api_v2_sessions_start_empty_session_post(
+                session_up_options=SessionUpOptions(
+                    project_id=project_id,
+                    name=session_name,
+                    cluster_config={"config": json.dumps(cluster_config)}
+                    if cluster_config
+                    else None,
+                    cloud_id=cloud_id,
+                )
+            ).result
+        session_id = up_response.session_id
+        second_update_required = up_response.second_update_required
+        wait_for_session_start(project_id, session_name, self.api_client)
+
+        # Push will sync project directory to working directory.
+        self.push(session_name, source=None, target=None, config=None, all_nodes=False)
+
+        if second_update_required:
+            with format_api_exception(ApiException):
+                self.api_client.setup_and_initialize_session_api_v2_sessions_session_id_setup_and_initialize_session_post(
                     session_id=session_id,
-                    stop_session_options=StopSessionOptions(
-                        terminate=True, workers_only=False, keep_min_workers=False,
+                    setup_initialize_session_options=SetupInitializeSessionOptions(
+                        project_id=project_id,
+                        cluster_config={"config": json.dumps(cluster_config)}
+                        if cluster_config
+                        else None,
                     ),
                 )
-                raise click.ClickException("{}\nSession startup failed.".format(e))
+
+            wait_for_session_start(project_id, session_name, self.api_client)
+
+        url = get_endpoint(f"/projects/{project_id}")
+        print(f"Session {session_name} started. View at {url}")
 
     def fork_session(
         self,
@@ -469,9 +573,8 @@ class SessionController:
             print(e)
             raise click.ClickException(e)  # type: ignore
 
-    def anyscale_push_session(
+    def push(
         self,
-        ctx: Any,
         session_name: str,
         source: Optional[str],
         target: Optional[str],
@@ -515,7 +618,7 @@ class SessionController:
                         target=None,
                         override_cluster_name=None,
                         down=False,
-                        all_nodes=True,
+                        all_nodes=all_nodes,
                     )
 
         if config:
