@@ -320,6 +320,7 @@ def wait_for_session_start(
     if api_client is None:
         api_client = get_api_client()
 
+    retry_count = 0
     while True:
         sessions = api_client.list_sessions_api_v2_sessions_get(
             project_id=project_id, name=session_name, active_only=False
@@ -328,7 +329,7 @@ def wait_for_session_start(
         if len(sessions) > 0:
             session = sessions[0]
 
-            if session.state == "Running":
+            if session.state == "Running" and session.pending_state is None:
                 return cast(str, session.id)
 
             # Check for start up errors
@@ -340,11 +341,18 @@ def wait_for_session_start(
                 raise click.ClickException(
                     f"Error while starting session {session_name}: {session.state_data.startup.startup_error}"
                 )
-            elif session.state and (
-                "Errored" in session.state or session.state in {"Terminated", "Stopped"}
-            ):
+            elif session.state and "Errored" in session.state:
                 raise click.ClickException(
-                    f"Error while starting session {session_name}: Session was stopped due to an error."
+                    f"Error while starting session {session_name}: Session startup failed due to an error."
+                )
+            elif (
+                retry_count >= 2
+                and session.state
+                and session.state in {"Terminated", "Stopped"}
+            ):
+                # Session is created in Terminated state; Ignore the first few state checks.
+                raise click.ClickException(
+                    f"Error while starting session {session_name}: Session is still in stopped/terminated state."
                 )
         else:
             raise click.ClickException(
@@ -352,6 +360,7 @@ def wait_for_session_start(
             )
 
         time.sleep(5)
+        retry_count += 1
 
 
 def install_anyscale_hooks(cluster_config: Dict[str, Any]) -> None:
