@@ -15,13 +15,13 @@ from anyscale.client.openapi_client import (  # type: ignore
 )
 
 
-@pytest.fixture()  # type: ignore
+@pytest.fixture()
 def base_mock_api_client() -> Mock:
     mock_api_client = Mock()
     return mock_api_client
 
 
-@pytest.fixture()  # type: ignore
+@pytest.fixture()
 def mock_api_client_with_session(
     base_mock_api_client: Mock, session_test_data: Session
 ) -> Mock:
@@ -31,7 +31,7 @@ def mock_api_client_with_session(
     return base_mock_api_client
 
 
-@pytest.fixture(scope="module")  # type: ignore
+@pytest.fixture(scope="module")
 def cloud_test_data() -> Cloud:
     return Cloud(
         id="cloud_id_1",
@@ -42,11 +42,11 @@ def cloud_test_data() -> Cloud:
         creator_id="creator_id",
         type="PUBLIC",
         created_at=datetime.now(timezone.utc),
-        config="{}",
+        config='{"max_stopped_instances": 0}',
     )
 
 
-@pytest.fixture(scope="module")  # type: ignore
+@pytest.fixture(scope="module")
 def project_test_data() -> Project:
     return Project(
         name="project_name",
@@ -61,7 +61,7 @@ def project_test_data() -> Project:
     )
 
 
-@pytest.fixture(scope="module")  # type: ignore
+@pytest.fixture(scope="module")
 def session_test_data() -> Session:
     return Session(
         id="session_id",
@@ -75,7 +75,7 @@ def session_test_data() -> Session:
     )
 
 
-@pytest.fixture(scope="module")  # type: ignore
+@pytest.fixture(scope="module")
 def session_start_error_test_data() -> Session:
     return Session(
         id="session_id",
@@ -92,7 +92,7 @@ def session_start_error_test_data() -> Session:
     )
 
 
-@pytest.fixture(scope="module")  # type: ignore
+@pytest.fixture(scope="module")
 def session_terminated_test_data() -> Session:
     return Session(
         id="session_id",
@@ -106,7 +106,7 @@ def session_terminated_test_data() -> Session:
     )
 
 
-@pytest.fixture(scope="module")  # type: ignore
+@pytest.fixture(scope="module")
 def session_command_test_data() -> SessionCommand:
     return SessionCommand(
         id="session_command_id",
@@ -118,7 +118,7 @@ def session_command_test_data() -> SessionCommand:
     )
 
 
-@pytest.fixture(scope="module")  # type: ignore
+@pytest.fixture(scope="module")
 def command_id_test_data() -> ExecuteCommandResponse:
     return ExecuteCommandResponse(
         command_id="command_id",
