@@ -17,7 +17,7 @@ from anyscale.controllers.list_controller import ListController
 from anyscale.util import humanize_timestamp
 
 
-@pytest.fixture()  # type: ignore
+@pytest.fixture()
 def mock_api_client(
     mock_api_client_with_session: Mock,
     cloud_test_data: Cloud,
@@ -151,7 +151,7 @@ def test_list_sessions_table(
     mock_load_project_or_throw.assert_called_once()
     mock_get_project_id.assert_called_once_with(mock_project_definition.root)
     mock_api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
-        project_id=session_test_data.project_id, name=None, active_only=False
+        project_id=session_test_data.project_id, name=None, active_only=False,
     )
     mock_api_client.get_session_commands_history_api_v2_session_commands_get.assert_called_once_with(
         session_id=session_test_data.id
@@ -296,6 +296,7 @@ def test_list_ips_json(
                         "provider": cloud_test_data.provider,
                         "region": cloud_test_data.region,
                         "credentials": cloud_test_data.credentials,
+                        "config": '{"max_stopped_instances": 0}',
                     },
                     "head-ip": "1.2.3.4",
                     "worker-ips": "",
