@@ -11,7 +11,7 @@ from anyscale.controllers.project_controller import ProjectController
 from anyscale.project import ProjectDefinition
 
 
-@pytest.fixture()  # type: ignore
+@pytest.fixture()
 def mock_api_client(project_test_data: Project) -> Mock:
     mock_api_client = Mock()
 
@@ -47,7 +47,7 @@ def test_clone_project(project_test_data: Project, mock_api_client: Mock) -> Non
     )
 
 
-@pytest.mark.parametrize("config", [None, "tmp.yaml"])  # type: ignore
+@pytest.mark.parametrize("config", [None, "tmp.yaml"])
 def test_init_project(
     project_test_data: Project, mock_api_client: Mock, config: str
 ) -> None:
