@@ -2,9 +2,10 @@ from datetime import datetime, timezone
 import json
 import os
 import tempfile
-from typing import Optional, Tuple
+from typing import Iterator, Optional, Tuple
 from unittest.mock import ANY, call, Mock, mock_open, patch
 
+import click
 import pytest
 import yaml
 
@@ -16,6 +17,7 @@ from anyscale.client.openapi_client import (  # type: ignore
     ProjectdefaultsessionnameResponse,
     ProjectListResponse,
     Session,
+    SessionFinishUpOptions,
     SessionListResponse,
     SessionResponse,
     SessionUpOptions,
@@ -27,7 +29,7 @@ from anyscale.controllers.session_controller import SessionController
 from anyscale.project import CLUSTER_YAML_TEMPLATE
 
 
-@pytest.fixture()  # type: ignore
+@pytest.fixture()
 def mock_api_client(mock_api_client_with_session: Mock) -> Mock:
     mock_api_client = mock_api_client_with_session
     mock_api_client.stop_session_api_v2_sessions_session_id_stop_post.return_value = (
@@ -70,7 +72,7 @@ def test_stop_single_session(session_test_data: Session, mock_api_client: Mock)
     mock_get_project_id.assert_called_once_with("/some/directory")
 
 
-@pytest.fixture()  # type: ignore
+@pytest.fixture()
 def mock_api_client_multiple_sessions(base_mock_api_client: Mock) -> Mock:
     base_mock_api_client.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
         results=[
@@ -158,13 +160,13 @@ def test_stop_multiple_sessions(mock_api_client_multiple_sessions: Mock) -> None
     mock_get_project_id.assert_called_once_with("/some/directory")
 
 
-@pytest.fixture()  # type: ignore
+@pytest.fixture()
 def mock_up_tuple(
     base_mock_api_client: Mock,
     project_test_data: Project,
     cloud_test_data: Cloud,
     session_test_data: Session,
-) -> Tuple[Mock, Project, Cloud]:
+) -> Iterator[Tuple[Mock, Project, Cloud, Mock]]:
     base_mock_api_client.get_session_api_v2_sessions_session_id_get = Mock(
         return_value=SessionResponse(result=session_test_data)
     )
@@ -172,8 +174,10 @@ def mock_up_tuple(
     mock_project_definition.root = "/some/directory"
     mock_popen_output = Mock()
     mock_popen_output.stdout = []
+    mock_popen_output.returncode = 0
     mock_popen_output.communicate = Mock()
     subprocess_mock = Mock(return_value=mock_popen_output)
+    mock_wait_for_session_start = Mock()
 
     with patch.multiple(
         "anyscale.controllers.session_controller",
@@ -185,13 +189,18 @@ def mock_up_tuple(
         download_anyscale_wheel=Mock(return_value=None),
         configure_for_session=Mock(return_value=yaml.safe_load(CLUSTER_YAML_TEMPLATE),),
         get_head_node_ip=Mock(return_value="1.2.3.4"),
-        wait_for_session_start=Mock(),
+        wait_for_session_start=mock_wait_for_session_start,
     ), patch.multiple("subprocess", Popen=subprocess_mock):
-        yield base_mock_api_client, project_test_data, cloud_test_data
+        yield base_mock_api_client, project_test_data, cloud_test_data, mock_wait_for_session_start
 
 
-def test_anyscale_up_success(mock_up_tuple: Tuple[Mock, Project, Cloud]) -> None:
-    mock_api_client, project_test_data, cloud_test_data = mock_up_tuple
+def test_anyscale_up_success(mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]) -> None:
+    (
+        mock_api_client,
+        project_test_data,
+        cloud_test_data,
+        mock_wait_for_start,
+    ) = mock_up_tuple
     session_controller = SessionController(api_client=mock_api_client)
     mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
         result=ProjectDefaultSessionName(name="session-11")
@@ -241,10 +250,76 @@ def test_anyscale_up_success(mock_up_tuple: Tuple[Mock, Project, Cloud]) -> None
     mock_api_client.session_up_api_v2_sessions_up_post.assert_called_once()
 
 
+def test_anyscale_up_failure(mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]) -> None:
+    (
+        mock_api_client,
+        project_test_data,
+        cloud_test_data,
+        mock_wait_for_start,
+    ) = mock_up_tuple
+    session_controller = SessionController(api_client=mock_api_client)
+    sesion_id = "session-10"
+    mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
+        result=ProjectDefaultSessionName(name="session-11")
+    )
+    mock_api_client.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
+        results=[]  # No session with this name yet, brand new session.
+    )
+    # Session Name should be "11"
+    mock_api_client.session_up_api_v2_sessions_up_post = Mock(
+        return_value=SessionupresponseResponse(
+            result=SessionUpResponse(
+                session_id=sesion_id,
+                cluster_name="new_cluster",
+                private_key="key",
+                cluster_config=yaml.safe_load(CLUSTER_YAML_TEMPLATE),
+                is_same_cluster_config=False,
+            )
+        )
+    )
+    mock_wait_for_start.side_effect = click.ClickException("Node Failed to Start!")
+
+    # We are setting the mock to return an error code
+    import subprocess
+
+    subprocess.Popen.return_value.returncode = 100  # type: ignore
+
+    with tempfile.NamedTemporaryFile(mode="w") as temp_file:
+        temp_file.write(CLUSTER_YAML_TEMPLATE)
+        temp_file.flush()
+        with pytest.raises(click.ClickException):
+            session_controller.up(
+                session_name=None,
+                config=temp_file.name,
+                min_workers=None,
+                max_workers=None,
+                no_restart=False,
+                restart_only=False,
+                disable_sync=False,
+                cloud_id=None,
+                cloud_name=None,
+                yes=True,
+            )
+        mock_api_client.session_finish_up_api_v2_sessions_session_id_finish_up_post.assert_called_once_with(
+            session_finish_up_options=SessionFinishUpOptions(
+                startup_log="",
+                new_session=True,
+                head_node_ip="1.2.3.4",
+                cluster_launch_errored=True,
+            ),
+            session_id=sesion_id,
+        )
+
+
 def test_anyscale_up_no_config_provided(
-    mock_up_tuple: Tuple[Mock, Project, Cloud]
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]
 ) -> None:
-    mock_api_client, project_test_data, cloud_test_data = mock_up_tuple
+    (
+        mock_api_client,
+        project_test_data,
+        cloud_test_data,
+        mock_wait_for_start,
+    ) = mock_up_tuple
     session_controller = SessionController(api_client=mock_api_client)
     mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
         result=ProjectDefaultSessionName(name="session-11")
@@ -291,9 +366,14 @@ def test_anyscale_up_no_config_provided(
 
 
 def test_anyscale_up_config_provided(
-    mock_up_tuple: Tuple[Mock, Project, Cloud]
+    mock_up_tuple: Tuple[Mock, Project, Cloud, Mock]
 ) -> None:
-    mock_api_client, project_test_data, cloud_test_data = mock_up_tuple
+    (
+        mock_api_client,
+        project_test_data,
+        cloud_test_data,
+        mock_wait_for_start,
+    ) = mock_up_tuple
     session_controller = SessionController(api_client=mock_api_client)
     mock_api_client.get_project_default_session_name_api_v2_projects_project_id_default_session_name_get.return_value = ProjectdefaultsessionnameResponse(
         result=ProjectDefaultSessionName(name="session-11")
@@ -601,16 +681,12 @@ def test_anyscale_push_session(
         validate_cluster_configuration=mock_validate_cluster_configuration,
         rsync=mock_rsync,
     ), patch.object(session_controller, "up", new=mock_up):
-        # TODO(mattweber): Remove the ctx argument?
-        ctx = None
         session_name = "TestSessionName"
         source = "TestSource"
         target = "TestTarget"
         config = "TestConfig"
         all_nodes = True
-        session_controller.anyscale_push_session(
-            ctx, session_name, source, target, config, all_nodes
-        )
+        session_controller.push(session_name, source, target, config, all_nodes)
 
         # Don't check the config_file argument because it's a random path of
         # a temporary file
@@ -641,7 +717,7 @@ def test_anyscale_push_session(
         )
 
 
-@pytest.mark.parametrize("config", [None, "tmp.yaml"])  # type: ignore
+@pytest.mark.parametrize("config", [None, "tmp.yaml"])
 def test_pull(
     session_test_data: Session, mock_api_client_with_session: Mock, config: str
 ) -> None:
@@ -691,7 +767,7 @@ def test_pull(
         )
 
 
-@pytest.mark.parametrize("project_name", ["project_name", None])  # type: ignore
+@pytest.mark.parametrize("project_name", ["project_name", None])
 def test_fork_session(
     session_test_data: Session,
     mock_api_client_with_session: Mock,
@@ -717,7 +793,7 @@ def test_fork_session(
     assert output_str == f"Session {session_test_data.name} started. View at {url}"
 
 
-@pytest.mark.parametrize("project_name", [None, "project_name"])  # type: ignore
+@pytest.mark.parametrize("project_name", [None, "project_name"])
 def test_resolve_session(
     project_test_data: Project,
     session_test_data: Session,
