@@ -107,15 +107,15 @@ def test_wait_for_session_start_terminated(
     mock_api_client_with_session.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
         results=[session_terminated_test_data]
     )
-    with pytest.raises(ClickException) as e:
+    with patch("time.sleep", Mock()), pytest.raises(ClickException) as e:
         wait_for_session_start(
             session_terminated_test_data.project_id,
             session_terminated_test_data.id,
             mock_api_client_with_session,
         )
 
-    assert "Session was stopped due to an error" in e.value.message
-    mock_api_client_with_session.list_sessions_api_v2_sessions_get.assert_called_once_with(
+    assert "Session is still in stopped/terminated state" in e.value.message
+    mock_api_client_with_session.list_sessions_api_v2_sessions_get.assert_called_with(
         project_id=session_terminated_test_data.project_id,
         name=session_terminated_test_data.id,
         active_only=False,
